==> haskell-json-0.10-152-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-json.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 json
version:              0.10
visibility:           public
id:                   json-0.10-1AqNbS7qXdAptUtscJPgY
key:                  json-0.10-1AqNbS7qXdAptUtscJPgY
license:              BSD-3-Clause
copyright:            (c) 2007-2018 Galois Inc.
maintainer:           Iavor S. Diatchki (iavor.diatchki@gmail.com)
author:               Galois Inc.
synopsis:             Support for serialising Haskell to and from JSON
description:
    JSON (JavaScript Object Notation) is a lightweight data-interchange
    format. It is easy for humans to read and write. It is easy for
    machines to parse and generate.  It is based on a subset of the
    JavaScript Programming Language, Standard ECMA-262 3rd Edition -
    December 1999.

    This library provides a parser and pretty printer for converting
    between Haskell values and JSON.

category:             Web
abi:                  7c109a474839a2babd0d29940ff61baa
exposed:              True
exposed-modules:
    Text.JSON Text.JSON.Generic Text.JSON.Pretty Text.JSON.ReadP
    Text.JSON.String Text.JSON.Types

import-dirs:          /usr/lib/ghc-9.2.8/site-local/json-0.10
library-dirs:         /usr/lib/ghc-9.2.8/site-local/json-0.10
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-json
hs-libraries:         HSjson-0.10-1AqNbS7qXdAptUtscJPgY
depends:
    array-0.5.4.0 base-4.16.4.0 bytestring-0.11.4.0 containers-0.6.5.1
    mtl-2.2.2 pretty-1.1.3.6 syb-0.7.2.4-3l4i7x4UWHaFMYIEmP3T6l
    text-1.2.5.0

haddock-interfaces:   /usr/share/doc/haskell-json/html/json.haddock
haddock-html:         /usr/share/doc/haskell-json/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-json-0.10-154-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-json.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 json
version:              0.10
visibility:           public
id:                   json-0.10-L8OmrIvHZfC7QEGgLMzbUG
key:                  json-0.10-L8OmrIvHZfC7QEGgLMzbUG
license:              BSD-3-Clause
copyright:            (c) 2007-2018 Galois Inc.
maintainer:           Iavor S. Diatchki (iavor.diatchki@gmail.com)
author:               Galois Inc.
synopsis:             Support for serialising Haskell to and from JSON
description:
    JSON (JavaScript Object Notation) is a lightweight data-interchange
    format. It is easy for humans to read and write. It is easy for
    machines to parse and generate.  It is based on a subset of the
    JavaScript Programming Language, Standard ECMA-262 3rd Edition -
    December 1999.

    This library provides a parser and pretty printer for converting
    between Haskell values and JSON.

category:             Web
abi:                  37387144dfb7ff809322f3702316dd59
exposed:              True
exposed-modules:
    Text.JSON Text.JSON.Generic Text.JSON.Pretty Text.JSON.ReadP
    Text.JSON.String Text.JSON.Types

import-dirs:          /usr/lib/ghc-9.2.8/site-local/json-0.10
library-dirs:         /usr/lib/ghc-9.2.8/site-local/json-0.10
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-json
hs-libraries:         HSjson-0.10-L8OmrIvHZfC7QEGgLMzbUG
depends:
    array-0.5.4.0 base-4.16.4.0 bytestring-0.11.4.0 containers-0.6.5.1
    mtl-2.2.2 pretty-1.1.3.6 syb-0.7.2.4-4iiIjHgm67gJA1HTgFmr8s
    text-1.2.5.0

haddock-interfaces:   /usr/share/doc/haskell-json/html/json.haddock
haddock-html:         /usr/share/doc/haskell-json/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
